Rails.application.routes.draw do
  post "/register/site" => "admin/register_api#register"
  post "/register/store_token" => "admin/register_api#send_store_token"
  get "/register/confirm_email" => "admin/register_api#confirm_email"
  get "/site/permissions"  => "admin/register_api#check_permissions"
  get "/site/send_email"  => "admin/register_api#send_email"
  
  locales = Site.first.in_use_locales rescue I18n.available_locales
  
  scope "(:locale)", locale: Regexp.new(locales.join("|")) do
    post "/xhr/site/re_register_url", to: 'admin/register_api#re_register_url'
    get 'git-auth' => 'registered_sites#git_auth'
    post 'git-auth' => 'registered_sites#git_auth'
    namespace :admin do
   		get "/registered_site/change_access/:uid" => "registered_sites#change_access_status"
    	resources :registered_sites,:except => ['show'] do 
        member do 
          get "progress"
        end
      end
      resource :registered_sites,:only => [] do
        post 'get_watch_list' => 'registered_sites#get_watch_list'
        get 'get_select_box' => 'registered_sites#get_select_box'
        get 'announcement' => 'registered_sites#announcement'
        get ':site_annc_id/edit_annc' => 'registered_sites#edit_annc'
        get ':site_annc_id/delete_annc' => 'registered_sites#delete_annc'
        post ':site_annc_id/update_annc' => 'registered_sites#update_annc'
        post 'get_check_log' => 'registered_sites#get_check_log'
        post 'check_all_site' => 'registered_sites#check_all_site'
        post 'destroy_bundle_temp' => 'registered_sites#destroy_bundle_temp'
        get 'bundle_update_remote_show' => 'registered_sites#bundle_update_remote_show'
        post "bundle_update" => 'registered_sites#bundle_update'
        post 'stop_bundle_update' => 'registered_sites#stop_bundle_update'
        post 'get_message' => 'registered_sites#get_message'
        post 'get_detail' => 'registered_sites#get_detail'
        post 'check_site' => 'registered_sites#check_site'
      end
    	resources :customization_logs do 
    		member do
    			get "get_log" => "customization_logs#get_log"
          post "archive" => "customization_logs#archive"
    		end
    	end
   end
  end
  
end
